@@ -12,7 +12,7 @@ class Command(NoArgsCommand):
     help = u"Show newsletters."
 
     def handle_noargs(self, **options):
-        from newsletter.models import Newsletter, PERIOD
+        from boletin.models import Newsletter, PERIOD
 
         only_pending = options.get('only_pending')
 
