@@ -34,7 +34,7 @@ class MangleTemplateTestCase(TestCase):
     def mangle_template_loaders(self):
         """Give priority to the app template loader to override the base
         template and avoid url reverse errors."""
-        template_loaders = settings.TEMPLATE_LOADERS
+        template_loaders = list(settings.TEMPLATE_LOADERS)
         app_template_loader = 'django.template.loaders.app_directories.load_template_source'
         if app_template_loader in template_loaders:
             template_loaders.remove(app_template_loader)
